@@ -7,14 +7,13 @@ Rev
 import corr, time, sys, numpy, os, logging
 
 def exit_fail():
-    print 'FAILURE DETECTED. Log entries:\n',lh.printMessages()
+    print 'FAILURE DETECTED. Log entries:\n',c.log_handler.printMessages()
     print "Unexpected error:", sys.exc_info()
-
     try:
         c.disconnect_all()
     except: pass
-    time.sleep(1)
-    raise
+    if verbose:
+        raise
     exit()
 
 def exit_clean():
@@ -23,24 +22,29 @@ def exit_clean():
     except: pass
     exit()
 
+
 if __name__ == '__main__':
     from optparse import OptionParser
 
     p = OptionParser()
     p.set_usage('%prog CONFIG_FILE')
     p.set_description(__doc__)
+    p.add_option('-v', '--verbose', dest='verbose',action='store_true', default=False,
+        help='Be verbose about errors.')
 
     opts, args = p.parse_args(sys.argv[1:])
 
     if args==[]:
-        print 'Please specify a configuration file! \nExiting.'
-        exit()
+        config_file=None
+    else:
+        config_file=args[0]
+    verbose=opts.verbose
 
 try:
     print 'Connecting...',
-    c=corr.corr_functions.Correlator(args[0],lh)
-    for logger in c.loggers: logger.setLevel(10)
-    print 'done.'
+    c=corr.corr_functions.Correlator(config_file=config_file,log_level=logging.DEBUG if verbose else logging.INFO,connect=False)
+    c.connect()
+    print 'done'
 
     print('\nKilling all 10GbE tgtap drivers...'),
     sys.stdout.flush()
