@@ -10,7 +10,8 @@ Revisions:\n
 import corr, time, sys, numpy, os, logging
 
 def exit_fail():
-    print 'FAILURE DETECTED. Log entries:\n',lh.printMessages()
+    print 'FAILURE DETECTED. Log entries:\n',
+    c.log_handler.printMessages()
     print "Unexpected error:", sys.exc_info()
     try:
         c.disconnect_all()
@@ -35,24 +36,21 @@ if __name__ == '__main__':
     p.set_description(__doc__)
     opts, args = p.parse_args(sys.argv[1:])
 
-    if args==[]:
-        print 'Please specify a configuration file! Exiting.'
-        exit()
-
     if not (opts.fengine or opts.xengine):
         print 'Either -f or -x (or both) must be supplied.'
         exit()
 
-lh=corr.log_handlers.DebugLogHandler()
+    if args==[]:
+        config_file=None
+    else:
+        config_file=args[0]
+    verbose=opts.verbose
 
-try:
-    print 'Creating correlator connections using config file \'%s\'...'%args[0],
-    c=corr.corr_functions.Correlator(args[0], lh)
-    if opts.xengine:
-        for s, server in enumerate(c.xsrvs): c.xloggers[s].setLevel(10)
-    if opts.fengine:
-        for s, server in enumerate(c.fsrvs): c.floggers[s].setLevel(10)
-    print 'done.'
+try:    
+    print 'Connecting...',
+    c=corr.corr_functions.Correlator(config_file=config_file,log_level=logging.DEBUG if verbose else logging.INFO, connect=False)
+    c.connect()
+    print 'done'
 
     print('\nCalculating all clocks...'),
     sys.stdout.flush()
