@@ -35,7 +35,7 @@ class DeviceExampleServer(katcp.DeviceServer):
         if self.c is None:
             return ("fail","... you haven't connected yet!")
         try:
-            rva, rvb, rvc = corr.corr_nb.channel_select(self.c, freq)
+            rva, rvb, rvc = corr.corr_nb.channel_select(c = self.c, freq_hz = freq)
             return ("ok", rva, rvb, rvc)
         except:
             return ("fail", "Something broke spectacularly. Check the log.")
@@ -259,9 +259,17 @@ class DeviceExampleServer(katcp.DeviceServer):
             if not (ant_str in self.c.config._get_ant_mapping_list()): 
                 return katcp.Message.reply(orgmsg.name,"fail","Antenna not found. Valid entries are: %s"%str(self.c.config._get_ant_mapping_list()))
             unpackedBytes=self.c.get_quant_snapshot(ant_str,n_spectra)
-            for s_n,spectrum in enumerate(unpackedBytes):
-                #print 'Sending inform %i:'%s,unpackedBytes[s]
-                self.reply_inform(sock, katcp.Message.inform(orgmsg.name,*(['%i+%ij'%(val.real,val.imag) for val in unpackedBytes[s_n]])),orgmsg)
+            print 'N spectra: %i.'%n_spectra
+            print unpackedBytes
+            if n_spectra == 1: 
+                self.reply_inform(sock, katcp.Message.inform(orgmsg.name,*(['%i+%ij'%(val.real,val.imag) for val in unpackedBytes[0]])),orgmsg)
+            elif n_spectra >1:
+                for s_n,spectrum in enumerate(unpackedBytes):
+                    #print 'Sending inform %i:'%s,unpackedBytes[s]
+                    print 'trying to send the array:', ['%i+%ij'%(val.real,val.imag) for val in unpackedBytes[0][s_n]]
+                    self.reply_inform(sock, katcp.Message.inform(orgmsg.name,*(['%i+%ij'%(val.real,val.imag) for val in unpackedBytes[0][s_n]])),orgmsg)
+            else:
+                raise RuntimeError("Please specify the number of spectra to be greater than zero!")
             return katcp.Message.reply(orgmsg.name,'ok',str(n_spectra))
         except:
             return katcp.Message.reply(orgmsg.name,'fail',"something broke. darn.")
@@ -339,15 +347,16 @@ class DeviceExampleServer(katcp.DeviceServer):
             return katcp.Message.reply(orgmsg.name,"fail","Antenna not found. Valid entries are %s."%str(self.c.config._get_ant_mapping_list()))
 
         eq_coeffs=[]
-        if len(orgmsg.arguments) != (self.c.config['n_chans']+1): #+1 to account for antenna label
+        if len(orgmsg.arguments) == 2: #+1 to account for antenna label, assume single number across entire band
+            self.c.eq_spectrum_set(ant_str,init_poly=[eval(orgmsg.arguments[1])])
+            return katcp.Message.reply(orgmsg.name,'ok',"Set all coefficients to %i."%eval(orgmsg.arguments[1]))
+        elif len(orgmsg.arguments) != (self.c.config['n_chans']+1): #+1 to account for antenna label
             return katcp.Message.reply(orgmsg.name,"fail","Sorry, you didn't specify the right number of coefficients (expecting %i, got %i)."%(self.c.config['n_chans'],len(orgmsg.arguments)-1))
-
-        for arg in orgmsg.arguments[1:]:
-            eq_coeffs.append(eval(arg))
-
-        self.c.eq_spectrum_set(ant_str,init_coeffs=eq_coeffs)
-
-        return katcp.Message.reply(orgmsg.name,'ok')
+        else:
+            for arg in orgmsg.arguments[1:]:
+                eq_coeffs.append(eval(arg))
+            self.c.eq_spectrum_set(ant_str,init_coeffs=eq_coeffs)
+            return katcp.Message.reply(orgmsg.name,'ok')
 
     def request_fr_delay_set(self, sock, orgmsg):
         """Set the fringe rate and delay compensation config for a given antenna. Parms: antpol, fringe_offset (degrees), fr_rate (Hz), delay (seconds), delay rate, load_time (Unix seconds), <ignore check>. If there is a seventh argument, don't do any checks to see if things loaded properly. If the load time is negative, load asap."""
