@@ -45,12 +45,13 @@ if  __name__ == '__main__':
     verbose=opts.verbose
 
 try:
+    raise RuntimeError('This script is farked. Don''t use it.')
+
     print 'Connecting...',
     c=corr.corr_functions.Correlator(config_file=config_file,log_level=logging.DEBUG if verbose else logging.INFO,connect=False)
     c.connect()
     print 'done'
 
-
     print 'F-engine TVGs:'
     kwargs = {}
 
@@ -63,10 +64,10 @@ try:
     
     if opts.tvg_fdfs == 1:
         print "\tEnabling FD,FS TVG"
-        kwargs["tvg_ffdel_sel"] = True
+        kwargs["tvgsel_fdfs"] = True
     elif opts.tvg_fdfs == 0:
         print "\tDisabling FD,FS TVG"
-        kwargs["tvg_ffdel_sel"] = False
+        kwargs["tvgsel_fdfs"] = False
 
     if opts.tvg_packetiser == 1:
         print "\tEnabling packetiser TVG"
