@@ -7,7 +7,7 @@ Revs:
 
 """
 
-import corr, numpy, time, struct, construct
+import corr, numpy, time, struct, construct, logging
 from construct import *
 
 def snapshots_get(fpgas,dev_names,man_trig=False,man_valid=False,wait_period=-1,offset=-1,circular_capture=False):
@@ -103,8 +103,8 @@ def get_adc_snapshots(correlator, ant_strs = [], trig_level = -1, sync_to_pps =
         fpgas.append(correlator.ffpgas[ffpga_n])
         dev_names.append('adc_snap%i' % feng_input)
 
-    if correlator.is_narrowband():
-        return corr.corr_nb.get_adc_snapshot(c = correlator, ant_names = ant_strs, trig_level = trig_level, sync_to_pps = sync_to_pps)
+    #if correlator.is_narrowband():
+    #    return corr.corr_nb.get_adc_snapshot(c = correlator, ant_names = ant_strs, trig_level = trig_level, sync_to_pps = sync_to_pps)
 
     init_mcnt = correlator.mcnt_current_get(ant_str = ant_strs[0])
     mcnt_lsbs = init_mcnt & 0xffffffff
@@ -131,8 +131,11 @@ def get_adc_snapshots(correlator, ant_strs = [], trig_level = -1, sync_to_pps =
        
     #return numpy.fromstring(self.ffpgas[ffpga_n].snapshot_get('adc_snap%i'%feng_input,man_trig=False,circular_capture=True,wait_period=-1)['data'],dtype=numpy.int8)        
 
-def get_quant_snapshot(correlator, ant_str, n_spectra = 1, pol = 0):
-    """Fetches a quantiser snapshot from hardware for a given antenna."""
+def get_quant_snapshot(correlator, ant_str, n_spectra = 1, man_trig = False, man_valid = False, wait_period = 2):
+    """
+    Fetches a quantiser snapshot from hardware for a single given antenna.
+    Returns a numpy array.
+    """
     if correlator.config['feng_bits'] != 4:
         raise RuntimeError('Sorry, this function is currently hard-coded to unpack 4 bit values')
     (ffpga_n, xfpga_n, fxaui_n, xxaui_n, feng_input) = correlator.get_ant_str_location(ant_str)
@@ -141,35 +144,41 @@ def get_quant_snapshot(correlator, ant_str, n_spectra = 1, pol = 0):
     fpga = correlator.ffpgas[ffpga_n]
     while ns < n_spectra:
         if correlator.is_wideband():
-            bram_dmp = fpga.snapshot_get('quant_snap%i' % feng_input, man_trig = False, wait_period = 2)
+            bram_dmp = fpga.snapshot_get('quant_snap%i' % feng_input, man_trig = man_trig, man_valid = man_valid, wait_period = wait_period)
             pckd_8bit = numpy.fromstring(bram_dmp['data'], dtype = numpy.uint8)
             for val in pckd_8bit:
                 # get the right 4 bit values:
-                pol_r_bits = (val & ((2**8) - (2**4))) >> 4
-                pol_i_bits = (val & ((2**4) - (2**0)))
+                r_bits = (val & ((2**8) - (2**4))) >> 4
+                i_bits = (val & ((2**4) - (2**0)))
                 # cast up to signed numbers:
-                unpacked_vals.append(float(((numpy.int8(pol_r_bits << 4) >> 4))) + (1j * float(((numpy.int8(pol_i_bits << 4) >> 4)))))
+                unpacked_vals.append(float(((numpy.int8(r_bits << 4) >> 4))) + (1j * float(((numpy.int8(i_bits << 4) >> 4)))))
         elif correlator.is_narrowband():
             # the narrowband snap block may be shorter than one spectrum, so make sure we get enough data
-            td = []
+            tempdata = []
             offset = 0
-            while len(td) < correlator.config['n_chans']:
-                #ttd = corr.corr_nb.get_snap_quant(correlator, [fpga], offset = offset)[0][pol]
-                ttd = corr.corr_nb.get_snap_quant_wbc_compat(correlator, [fpga], offset = offset)[0][pol]
-                td.extend(ttd)
-                offset = offset + len(ttd)
-            unpacked_vals.extend(td)
+            while len(tempdata) < correlator.config['n_chans']:
+                #quanttemp = corr.corr_nb.get_snap_quant(correlator, [fpga], offset = offset)[0][feng_input]
+                logging.debug('get_quant_snapshot: nb, read snap - have %i/%i channels' % (len(tempdata), correlator.config['n_chans']))
+                quanttemp = corr.corr_nb.get_snap_quant_wbc_compat(correlator, [fpga], offset = offset)[0][feng_input]
+                tempdata.extend(quanttemp)
+                # the debug snap block is 1024 128-bit words, so it's 16kbytes long. The offset is in BYTES!
+                # the data in tempdata represents 128-bit WORDS
+                offset = offset + (len(quanttemp) * 128/8)
+            unpacked_vals.extend(tempdata)
         else:
             raise RuntimeError('Unknown mode.')
         ns = len(unpacked_vals) / correlator.config['n_chans']
+        logging.debug('get_quant_snapshot: got spectrum %i/%i' % (ns, n_spectra))
     rv = numpy.array(unpacked_vals)
     if len(rv) % correlator.config['n_chans'] != 0:
-        raise RuntimeError('Retrieved data is not a multiple of n_chans. Something is wrong.')
-    rv.shape = (len(unpacked_vals) / correlator.config['n_chans'], correlator.config['n_chans'])
-    if n_spectra == 0:
-        return rv[0]
+        raise RuntimeError('Retrieved data is not a multiple of n_chans, something is wrong.')
+    rv.shape = (ns, correlator.config['n_chans'])
+    if ns < n_spectra:
+        raise RuntimeError('Needed %i spectra, but only ended up with %i, something is wrong.' % (n_spectra, ns))
+    if n_spectra == 1:
+        return rv[0], 1
     else:
-        return rv[0:n_spectra, :]
+        return rv[0:n_spectra, :], n_spectra
 
 def Swapped(subcon):
     """swaps the bytes of the stream, prior to parsing"""
